@@ -30,6 +30,7 @@ def vf_bmap() -> dict[str, str]:
     }
     for k in (
         "dedup",
+        "dlni",
         "dotsrch",
         "e2d",
         "e2ds",
@@ -94,13 +95,16 @@ def vf_vmap() -> dict[str, str]:
     }
     for k in (
         "bup_ck",
+        "cachectl",
         "casechk",
         "chmod_d",
         "chmod_f",
         "dbd",
         "du_who",
+        "epilogues",
         "ufavico",
         "forget_ip",
+        "fsnt",
         "hsortn",
         "html_head",
         "html_head_s",
@@ -121,10 +125,16 @@ def vf_vmap() -> dict[str, str]:
         "og_tpl",
         "og_ua",
         "opds_exts",
+        "prologues",
+        "preadmes",
         "put_ck",
         "put_name",
+        "readmes",
         "mv_retry",
         "rm_retry",
+        "rss_sort",
+        "rss_fmt_t",
+        "rss_fmt_d",
         "shr_who",
         "sort",
         "tail_fd",
@@ -132,6 +142,7 @@ def vf_vmap() -> dict[str, str]:
         "tail_tmax",
         "tail_who",
         "tcolor",
+        "th_qv",
         "th_spec_p",
         "txt_eol",
         "unlist",
@@ -200,10 +211,12 @@ flagcats = {
         "noclone": "take dupe data from clients, even if available on HDD",
         "nodupe": "rejects existing files (instead of linking/cloning them)",
         "nodupem": "rejects existing files during moves as well",
+        "casechk=auto": "actively prevent case-insensitive filesystem? y/n",
         "chmod_d=755": "unix-permission for new dirs/folders",
         "chmod_f=644": "unix-permission for new files",
         "uid=573": "change owner of new files/folders to unix-user 573",
         "gid=999": "change owner of new files/folders to unix-group 999",
+        "fsnt=auto": "filesystem filename traits (lin/win/mac/auto)",
         "wram": "allow uploading into ramdisks",
         "sparse": "force use of sparse files, mainly for s3-backed storage",
         "nosparse": "deny use of sparse files, mainly for slow storage",
@@ -265,7 +278,6 @@ flagcats = {
         "no_db_ip": "never store uploader-IP in the db; disables unpost",
         "fat32": "avoid excessive reindexing on android sdcardfs",
         "dbd=[acid|swal|wal|yolo]": "database speed-durability tradeoff",
-        "casechk=auto": "actively prevent case-insensitive filesystem? y/n",
         "xlink": "cross-volume dupe detection / linking (dangerous)",
         "xdev": "do not descend into other filesystems",
         "xvol": "do not follow symlinks leaving the volume root",
@@ -288,6 +300,7 @@ flagcats = {
         "thsize": "thumbnail res; WxH",
         "crop": "center-cropping (y/n/fy/fn)",
         "th3x": "3x resolution (y/n/fy/fn)",
+        "th_qv=40": "thumbnail quality (10~90)",
         "convt": "convert-to-image timeout in seconds",
         "aconvt": "convert-to-audio timeout in seconds",
         "th_spec_p=1": "make spectrograms? 0=never 1=fallback 2=always",
@@ -318,6 +331,7 @@ flagcats = {
         "hsortn": "number of sort-rules to add to media URLs",
         "ufavico=URL": "per-volume favicon (.ico/png/gif/svg)",
         "unlist": "dont list files matching REGEX",
+        "dlni": "force-download (no-inline) files on click",
         "html_head=TXT": "includes TXT in the <head>, or @PATH for file at PATH",
         "html_head_s=TXT": "additional static text in the html <head>",
         "tcolor=#fc0": "theme color (a hint for webbrowsers, discord, etc.)",
@@ -327,6 +341,10 @@ flagcats = {
         "norobots": "kindly asks search engines to leave",
         "unlistcr": "don't list read-access in controlpanel",
         "unlistcw": "don't list write-access in controlpanel",
+        "prologues=.prologue.html": "files to embed above/before files",
+        "epilogues=.epilogue.html": "files to embed below/after files",
+        "readmes=readme.md,README.md": "files to embed as readmes",
+        "preadmes=preadme.md,PREADME.md": "files to embed as preadmes",
         "no_sb_md": "disable js sandbox for markdown files",
         "no_sb_lg": "disable js sandbox for prologue/epilogue",
         "sb_md": "enable js sandbox for markdown files (default)",
@@ -379,6 +397,12 @@ flagcats = {
         "tail_tmax=30": "kill connection after 30 sec",
         "tail_who=2": "restrict ?tail access (1=admins,2=authed,3=everyone)",
     },
+    "rss": {
+        "rss": "allow '?rss' URL suffix (experimental)",
+        "rss_sort=m": "default sort-order (m/u/n/s)",
+        "rss_fmt_t={fname}": "default title-format",
+        "rss_fmt_d={album},{.tn}": "default description-format",
+    },
     "others": {
         "dots": "allow all users with read-access to\nenable the option to show dotfiles in listings",
         "fk=8": 'generates per-file accesskeys,\nwhich are then required at the "g" permission;\nkeys are invalidated if filesize or inode changes',
@@ -386,7 +410,6 @@ flagcats = {
         "dk=8": 'generates per-directory accesskeys,\nwhich are then required at the "g" permission;\nkeys are invalidated if filesize or inode changes',
         "dks": "per-directory accesskeys allow browsing into subdirs",
         "dky": 'allow seeing files (not folders) inside a specific folder\nwith "g" perm, and does not require a valid dirkey to do so',
-        "rss": "allow '?rss' URL suffix (experimental)",
         "rmagic": "expensive analysis for mimetype accuracy",
         "shr_who=auth": "who can create shares? no/auth/a",
         "unp_who=2": "unpost only if same... 1=ip+name, 2=ip, 3=name",
@@ -397,6 +420,7 @@ flagcats = {
         "zipmaxt=no": "reply with 'no' if download-as-zip exceeds max",
         "zipmaxu": "zip-size-limit does not apply to authenticated users",
         "nopipe": "disable race-the-beam (download unfinished uploads)",
+        "cachectl=no-cache": "controls caching in webbrowsers",
         "mv_retry": "ms-windows: timeout for renaming busy files",
         "rm_retry": "ms-windows: timeout for deleting busy files",
         "davauth": "ask webdav clients to login for all folders",
