@@ -382,7 +382,7 @@ class Tftpd(object):
                     None,
                 )
                 t = hr.get("rejectmsg") or ""
-                if t or not hr:
+                if t or hr.get("rc") != 0:
                     if not t:
                         t = "upload blocked by xbu server config: %r" % (vpath,)
                     yeet(t)
